@@ -26,7 +26,12 @@ catmeth <- function(method,
                     pscale = 1,
                     irscale = 1,
                     irunit = "person-years",
-                    null.effect = NA) {
+                    null.effect = NA,
+                    big.mark = "",
+                    digits = gs("digits"),
+                    digits.tau2 = gs("digits.tau2"),
+                    text.tau2 = gs("text.tau2")
+                    ) {
   
   if (is.null(allstudies)) allstudies <- FALSE
   if (is.null(doublezeros)) doublezeros <- FALSE
@@ -40,7 +45,7 @@ catmeth <- function(method,
     sm.details <- "\n- Freeman-Tukey double arcsine transformation"
   else if (sm == "PAS")
     sm.details <- "\n- Arcsine transformation"
-  else if (sm == "PLN" | sm == "IRLN")
+  else if (is.log.effect(sm))
     sm.details <- "\n- Log transformation"
   else if (sm == "PLOGIT")
     sm.details <- "\n- Logit transformation"
@@ -52,6 +57,9 @@ catmeth <- function(method,
   else if  (sm == "IRS")
     sm.details <- "\n- Square root transformation"
   ##
+  else if  (sm == "MRAW")
+    sm.details <- "\n- Untransformed (raw) means"
+  ##
   else
     sm.details <- ""
   ##
@@ -155,36 +163,41 @@ catmeth <- function(method,
   if (pscale != 1)
     sm.details <- paste(sm.details,
                         "\n- Events per ",
-                        format(pscale, scientific = FALSE),
+                        format(pscale, scientific = FALSE,
+                               big.mark = big.mark),
                         " observations", sep = "")
   ##
   if (irscale != 1)
     sm.details <- paste(sm.details,
                         "\n- Events per ",
-                        format(irscale, scientific = FALSE),
+                        format(irscale, scientific = FALSE,
+                               big.mark = big.mark),
                         " ", irunit, sep = "")
 
   if (!is.na(null.effect) && null.effect != 0) {
     if (pscale != 1)
       sm.details <- paste(sm.details,
                           "\n- Null hypothesis: effect is equal to ",
-                          format(round(null.effect * pscale, gs("digits")),
-                                 scientific = FALSE),
+                          format(round(null.effect * pscale, digits),
+                                 scientific = FALSE, big.mark = big.mark),
                           " events per ",
-                          format(pscale, scientific = FALSE),
+                          format(pscale, scientific = FALSE,
+                                 big.mark = big.mark),
                           " observations", sep = "")
     else if (irscale != 1)
       sm.details <- paste(sm.details,
                           "\n- Null hypothesis: effect is equal to ",
-                          format(round(null.effect * irscale, gs("digits")),
-                                 scientific = FALSE),
+                          format(round(null.effect * irscale, digits),
+                                 scientific = FALSE, big.mark = big.mark),
                           " events per ",
-                          format(irscale, scientific = FALSE),
+                          format(irscale, scientific = FALSE,
+                                 big.mark = big.mark),
                           " ", irunit, sep = "")
     else
       sm.details <- paste(sm.details,
                           "\n- Null hypothesis: effect is equal to ",
-                          format(null.effect, scientific = FALSE),
+                          format(null.effect, scientific = FALSE,
+                                 big.mark = big.mark),
                           sep = "")
   }
   
@@ -196,14 +209,10 @@ catmeth <- function(method,
   else {
     if (!is.null(tau.preset)) {
       tau2 <- tau.preset^2
-      if (tau2 > 0 & tau2 < 0.0001)
-        tau2 <- paste("tau^2", format.tau(tau2))
-      else
-        tau2 <- paste("tau^2 = ",
-                      ifelse(tau2 == 0,
-                             "0",
-                             format(round(tau2, 4), 4, nsmall = 4, scientific = FALSE)),
-                      sep = "")
+      tau2 <- formatPT(tau2, lab = TRUE, labval = text.tau2,
+                       digits = digits.tau2,
+                       lab.NA = "NA",
+                       big.mark = big.mark)
       ##
       lab.method.tau <- paste("\n- Preset between-study variance: ",
                               tau2, sep = "")
