@@ -51,6 +51,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   ## (1) Check arguments
   ##
   ##
+  chknull(sm)
   chklevel(level)
   chklevel(level.comb)
   chklogical(comb.fixed)
@@ -74,7 +75,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   ##
   fun <- "metabin"
   ##
-  sm <- setchar(sm, c("OR", "RD", "RR", "ASD"))
+  sm <- setchar(sm, .settings$sm4bin)
   ##
   method <- setchar(method, c("Inverse", "MH", "Peto", "GLMM"))
   if (method == "GLMM") {
