@@ -268,6 +268,15 @@ summary.meta <- function(object,
     class(res) <- c(class(res), "metacor")
   }
   ##
+  if (inherits(object, "metagen")) {
+    res$n.e <- object$n.e
+    res$n.c <- object$n.c
+    ##
+    res$null.effect <- object$null.effect
+    ##
+    class(res)  <- c(class(res), "metagen")
+  }
+  ##
   if (inherits(object, "metainc")) {
     class(res)  <- c(class(res), "metainc")
     res$sparse  <- object$sparse
@@ -280,6 +289,16 @@ summary.meta <- function(object,
     res$.glmm.random <- object$.glmm.random
   }
   ##
+  if (inherits(object, "metamean")) {
+    res$n    <- object$n
+    res$mean <- object$mean
+    res$sd   <- object$sd
+    ##
+    res$null.effect <- object$null.effect
+    ##
+    class(res)  <- c(class(res), "metamean")
+  }
+  ##
   if (metaprop) {
     res$event <- object$event
     res$n     <- object$n
@@ -339,6 +358,9 @@ summary.meta <- function(object,
     class(res) <- c(class(res), "trimfill")
   }
   ##
+  if (inherits(object, "metabind"))
+    class(res) <- c(class(res), "metabind")
+  ##
   res$complab <- object$complab
   res$outclab <- object$outclab
   res$title   <- object$title
